parse_append_command

Function parse_append_command 

pub fn parse_append_command(
    input: &str,
    literal_data: Vec<u8>,
) -> Result<(String, ImapCommand), String>
Parse APPEND command with literal data This is separate because it needs access to the full input including literal data